﻿/// <reference path="../../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../../rubbish.ts"/>

ko.bindingHandlers.noSubmit = {
    init: function (element, valueAccessor, allBindingsAccessor, viewModel) {
        $(element).keydown(function (e) {
            var keyCode = e.which || e.keyCode;
            if (keyCode == 13 || keyCode == 10) {
                $(e.target).blur();
                return false;
            }

            return true;
        });
    }
};

var IndexingServerViewModel = (function () {
    function IndexingServerViewModel(data) {
        var _this = this;
        this.name = data.name;
        this.address = ko.observable(data.address);
        this.updated = ko.observable(data.updated);
        this.primary = ko.observable(data.primary);
        this.stale = ko.observable(data.stale);
        this.updatedText = ko.computed(function () {
            var time = _this.updated();
            if (_this.primary())
                return time + ' (primary)';
            if (_this.stale())
                return time + ' (stale)';
            return time;
        });
    }
    IndexingServerViewModel.prototype.update = function (data) {
        this.address(data.address);
        this.updated(data.updated);
        this.primary(data.primary);
        this.stale(data.stale);
    };
    return IndexingServerViewModel;
})();

var IndexingServersPageViewModel = (function () {
    function IndexingServersPageViewModel(input) {
        var _this = this;
        this.updateUrl = input.updateUrl;
        this.deleteUrl = input.deleteUrl;
        this.setFailoverUrl = input.setFailoverUrl;
        this.failoverPeriod = ko.observable(input.failoverPeriod);
        this.editFailoverPeriod = ko.observable(false);
        this.servers = ko.observableArray(input.servers.map(function (s) {
            return new IndexingServerViewModel(s);
        }));

        if (this.updateUrl) {
            var makeAjaxRequest = function () {
                $.ajax({
                    url: _this.updateUrl,
                    type: 'POST',
                    success: function (data) {
                        return _this.updateServers(data);
                    },
                    complete: function () {
                        return setTimeout(makeAjaxRequest, 5000);
                    }
                });
            };

            setTimeout(makeAjaxRequest, 5000);
        }

        this.editFailoverPeriod.subscribe(function (isEditModeEnabled) {
            if (!isEditModeEnabled) {
                $.ajax({
                    url: _this.setFailoverUrl,
                    data: { minutes: _this.failoverPeriod() },
                    type: 'POST',
                    success: function (data) {
                        return _this.failoverPeriod(data);
                    }
                });
            }
        });
    }
    IndexingServersPageViewModel.prototype.deleteClick = function (server) {
        var _this = this;
        if (confirm('Are you sure you want to delete ' + server.name + '?')) {
            $.ajax({
                url: this.deleteUrl,
                data: { name: server.name },
                type: 'POST',
                success: function (data) {
                    return _this.updateServers(data);
                }
            });
        }
    };

    IndexingServersPageViewModel.prototype.editFailoverPeriodClick = function () {
        this.editFailoverPeriod(true);
    };

    IndexingServersPageViewModel.prototype.updateServers = function (servers) {
        if (servers.length == this.servers().length) {
            var doUpdate = true;

            for (var i = 0; i < servers.length; i++) {
                if (servers[i].name != this.servers()[i].name) {
                    doUpdate = false;
                    break;
                }
            }

            if (doUpdate) {
                for (var i = 0; i < servers.length; i++)
                    this.servers()[i].update(servers[i]);

                return;
            }
        }

        this.servers.removeAll();
        for (var i = 0; i < servers.length; i++)
            this.servers.push(new IndexingServerViewModel(servers[i]));
    };
    return IndexingServersPageViewModel;
})();
