﻿/// <reference path="../../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../../rubbish.ts"/>

var MavenArtifactSummaryViewModel = (function () {
    function MavenArtifactSummaryViewModel(data, feedName) {
        var _this = this;
        this.groupId = data.groupId;
        this.artifactId = data.artifactId;
        this.name = data.name;
        this.description = data.description;
        this.downloads = data.downloads;
        this.isLocal = data.isLocal;
        this.latestVersion = data.latestVersion;

        this.displayName = ko.computed(function () {
            return _this.name || _this.artifactId;
        });
        this.url = ko.computed(function () {
            return '/maven-feeds/' + encodeURIComponent(feedName) + '/' + encodeURIComponent(_this.groupId).replace(/\./g, '/') + '/' + encodeURIComponent(_this.artifactId) + '/' + encodeURIComponent(_this.latestVersion);
        });
    }
    return MavenArtifactSummaryViewModel;
})();

var MavenConnectorIndexingStatusViewModel = (function () {
    function MavenConnectorIndexingStatusViewModel(data) {
        this.url = ko.observable(data.url);
        this.percent = ko.observable(data.percent);
    }
    return MavenConnectorIndexingStatusViewModel;
})();

var BrowseMavenFeedPageViewModel = (function () {
    function BrowseMavenFeedPageViewModel(data) {
        var _this = this;
        this.indexingConnector = ko.observable(null);
        this.browseUrl = data.browseUrl;
        this.searchUrl = data.searchUrl;
        this.feedId = data.feedId;
        this.feedName = data.feedName;
        this.searchTerm = ko.observable('');
        this.maxResults = ko.observable(20);
        this.artifacts = ko.observableArray();
        this.isLoading = ko.observable(true);

        this.emptyPackagesMessage = ko.computed(function () {
            if (_this.isLoading() || (_this.artifacts() && _this.artifacts().length > 0))
                return '';

            if (_this.searchTerm())
                return "No artifacts found.";
            else
                return "No local artifacts to display. Use the search box to search connectors.";
        });

        this.resultSourceName = ko.computed(function () {
            if (_this.searchTerm())
                return "matching";
            else
                return "local";
        });

        this.update();

        this.searchTerm.subscribe(function (v) {
            return _this.update();
        });
        this.maxResults.subscribe(function (v) {
            return _this.update();
        });

        $('form').submit(function () {
            _this.searchTerm($('.package-search > input').val());
            return false;
        });

        var updateIndexingStatus = function () {
            $.ajax({
                url: data.indexingStatusUrl,
                type: 'POST',
                data: { feedId: data.feedId },
                success: function (status) {
                    var current = _this.indexingConnector();
                    if (!current && status) {
                        _this.indexingConnector(new MavenConnectorIndexingStatusViewModel(status));
                    } else if (current && !status) {
                        _this.indexingConnector(null);
                    } else if (current && status) {
                        current.percent(status.percent);
                        current.url(status.url);
                    }
                },
                complete: function () {
                    window.setTimeout(updateIndexingStatus, 10000);
                }
            });
        };

        updateIndexingStatus();
    }
    BrowseMavenFeedPageViewModel.prototype.update = function () {
        var _this = this;
        this.isLoading(true);
        this.artifacts.removeAll();

        var url;
        var data;
        if (this.searchTerm()) {
            url = this.searchUrl;
            data = { feedId: this.feedId, searchTerm: this.searchTerm(), maxResults: this.maxResults() };
        } else {
            url = this.browseUrl;
            data = { feedId: this.feedId, maxResults: this.maxResults() };
        }

        $.ajax({
            url: url,
            data: data,
            type: 'POST',
            success: function (result) {
                _this.artifacts(result.map(function (a) {
                    return new MavenArtifactSummaryViewModel(a, _this.feedName);
                }));
                _this.isLoading(false);
            }
        });
    };
    return BrowseMavenFeedPageViewModel;
})();
